==> gatsby-theme-backend-1.0.14.tgz: package/src/services/auth.js <==
import GoTrue from "gotrue-js"
import { navigate } from "gatsby"
import { notification } from "antd"

const isBrowser = typeof window !== "undefined"
const gotrue = new GoTrue({
	APIUrl: `https://${process.env.GATSBY_NETLIFY_SITE_DOMAIN}/.netlify/identity`,
	audience: "",
	setCookie: true,
})

export const isAuthenticated = () => {
	if (!isBrowser) {
		return false
	}

	const user = gotrue.currentUser()
	if (user && user.email) {
		return true
	}

	return false
}
export const getProfile = () => {
	if (!isBrowser) {
		return null
	}

	const user = gotrue.currentUser()
	return user
}
export const isAdministrator = () => {
	if (!isBrowser) {
		return false
	}

	const user = gotrue.currentUser()
	if (
		user.app_metadata.roles &&
		user.app_metadata.roles.indexOf("Administrator") > -1
	) {
		return true
	}

	return false
}
export const logout = () => {
	const user = gotrue.currentUser()
	user
		.logout()
		.then(() => {
			if (isBrowser) {
				navigate("/")
			} else {
				console.log("Can not logout in none browser!")
			}
		})
		.catch((error) => {
			console.log("Failed to logout user: %o", error)
			throw error
		})
}

export const fetchLogin = (email, password, remember) => {
	const cango = gotrue
		.login(email, password, remember)
		.then(() => {
			return true
		})
		.catch((error) => {
			console.log("error ", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.error_description,
				duration: 0,
			})
			return false
		})
	return cango
}

export const fetchSignUp = (email, password) => {
	const cango = gotrue
		.signup(email, password)
		.then(() => {
			fetchLogin(email, password, true)
			return true
		})
		.catch((error) => {
			console.log("error ", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.msg,
				duration: 0,
			})
			return false
		})
	return cango
}

==> gatsby-theme-backend-1.0.16.tgz: package/src/services/auth.js <==
import GoTrue from "gotrue-js"
import { navigate } from "gatsby"
import { notification } from "antd"

const isBrowser = typeof window !== "undefined"
const gotrue = new GoTrue({
	APIUrl: `https://${process.env.GATSBY_NETLIFY_SITE_DOMAIN}/.netlify/identity`,
	audience: "",
	setCookie: true,
})

export const isAuthenticated = () => {
	if (!isBrowser) {
		return false
	}

	const user = gotrue.currentUser()
	if (user && user.email) {
		return true
	}

	return false
}
export const getProfile = () => {
	if (!isBrowser) {
		return null
	}

	const user = gotrue.currentUser()
	return user
}
export const isAdministrator = () => {
	if (!isBrowser) {
		return false
	}

	const user = gotrue.currentUser()
	if (
		user.app_metadata.roles &&
		user.app_metadata.roles.indexOf("Administrator") > -1
	) {
		return true
	}

	return false
}
export const logout = () => {
	const user = gotrue.currentUser()
	user
		.logout()
		.then(() => {
			if (isBrowser) {
				navigate("/")
			} else {
				console.log("Can not logout in undefined window!")
				notification["error"]({
					message: "Error",
					description: "Can not logout in undefined window!",
					duration: 0,
				})
			}
		})
		.catch((error) => {
			console.log("Failed to logout user: %o", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.error_description,
				duration: 0,
			})
			//throw error
		})
}

export const fetchLogin = (email, password, remember) => {
	const cango = gotrue
		.login(email, password, remember)
		.then(() => {
			return true
		})
		.catch((error) => {
			console.log("error ", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.error_description,
				duration: 0,
			})
			return false
		})
	return cango
}

export const fetchSignUp = (email, password) => {
	const cango = gotrue
		.signup(email, password)
		.then(() => {
			//fetchLogin(email, password, true)
			return true
		})
		.catch((error) => {
			console.log("error ", error)
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.msg,
				duration: 0,
			})
			return false
		})
	return cango
}

export default gotrue
